SKILL Standard library
======================

Virtue includes a standard library of functions that extend Virtuoso's library
of built-in functions.

See the :doc:`../reference/skill_api/index` page and the
`source code <https://github.com/cascode-labs/virtue/tree/main/virtue>`_
for more details.
